@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # Base class for Rana device-specific modules
@@ -21,13 +20,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_module import ranaModule
+from modules.base_module import RanaModule
 
-class deviceModule(ranaModule):
+class DeviceModule(RanaModule):
   """A modRana device module"""
   
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
+    RanaModule.__init__(self, m, d, i)
 
   def getDeviceIDString(self):
     """
@@ -82,12 +81,29 @@ class deviceModule(ranaModule):
     return False
 
   def getSupportedGUIModuleIds(self):
-    """
-    supported GUI module IDs, ordered by preference from left to right
-    (the most-preferred should be on the left)
+    """supported GUI module IDs, ordered by preference from left to right
+
+    THE ":" NOTATION
+    single GUI modules might support different subsets, the usability of
+    these subsets can vary based on the current platform
+    -> this functions enabled device modules to report which GUI subsets
+    are most suitable for the given platform
+    -> the string starts with the module id prefix, is separated by : and
+    continues with the subset id
+    EXAMPLE: ["QML:harmattan","QML:indep","GTK"]
+    -> QML GUI with Harmattan Qt Components is preferred,
+    QML GUI with platform independent Qt Components is less preferred
+    and the GTK GUI is set as a fallback if everything else fails
+    CURRENT USAGE
+    there are different incompatible native Qt Component sets
+    on various platforms (Harmattan QTC, Plasma Active QTC, Jolla QTC,...)
+    the QML GUI aims to support most of these components sets to provide
+    native look & feel and the subset id is used by the device module
+    to signal the GUI module which QTC component to use
     """
     return ["GTK", "QML"] # as default try GTK first and then QML
 
+
   def handlesLocation(self):
     """report whether the device module handles position updates by itself"""
     return False
@@ -159,7 +175,7 @@ class deviceModule(ranaModule):
     widget/dialog"""
     return False
 
-  def startLocation(self):
+  def startLocation(self, startMainLoop=False):
     """start handling location - check handlesLocation if this is supported"""
     pass
 
@@ -230,11 +246,3 @@ class deviceModule(ranaModule):
 #
 #  def disableAutorotation(self):
 #    pass
-
-
-
-if(__name__ == "__main__"):
-  a = example({}, {})
-  a.update()
-  a.update()
-  a.update()
