@@ -124,6 +124,9 @@ class QMLGUI(GUIModule):
     self.view.engine().addImageProvider("tiles", self.tilesProvider)
 
     rc = self.view.rootContext()
+    # make core modRana functionality accessible from QML
+    modRanaCore = ModRana(self.modrana)
+    rc.setContextProperty("modrana", modRanaCore)
     # make options accessible from QML
     options = Options(self.modrana)
     rc.setContextProperty("options", options)
@@ -140,6 +143,10 @@ class QMLGUI(GUIModule):
     tiles = MapTiles(self)
     rc.setContextProperty("mapTiles", tiles)
 
+    # make constants accessible
+    self.constants = self.getConstants()
+    rc.setContextProperty("C", self.constants)
+
     self.window.closeEvent = self._qtWindowClosed
     #self.window.show()
 
@@ -266,6 +273,11 @@ class QMLGUI(GUIModule):
       return None
 
 
+  def getConstants(self):
+    C = {
+    }
+    return C
+
 class Platform(QtCore.QObject):
   """make current platform available to QML and integrable as a property"""
 
@@ -697,6 +709,50 @@ class GPSDataWrapper(QtCore.QObject):
   mode = QtCore.Property(str, _gps_mode, notify=changed)
 
 
+class ModRana(QtCore.QObject):
+  """
+  core modRana functionality
+  """
+
+  def __init__(self, modrana):
+    QtCore.QObject.__init__(self)
+    self.modrana = modrana
+    self.modrana.watch("mode", self._modeChangedCB)
+    self.modrana.watch("theme", self._themeChangedCB)
+
+  # mode
+
+  def _getMode(self):
+    return self.modrana.get('mode', "car")
+
+  def _setMode(self, mode):
+    self.modrana.set('mode', mode)
+
+  modeChanged = Signal()
+
+  def _modeChangedCB(self, *args):
+    """notify when the mode key changes in options"""
+    self.modeChanged.emit()
+
+  # theme
+
+  def _getTheme(self):
+    return self.modrana.get('theme', "default")
+
+  def _setTheme(self, newTheme):
+    return self.modrana.set('theme', newTheme)
+
+  themeChanged = Signal()
+
+  def _themeChangedCB(self, *args):
+    """notify when the mode key changes in options"""
+    self.themeChanged.emit()
+
+  # properties
+
+  mode = QtCore.Property(str, _getMode, _setMode, notify=modeChanged)
+  theme = QtCore.Property(str, _getTheme, _setTheme, notify=themeChanged)
+
 class Options(QtCore.QObject):
   """make options available to QML and integrable as a property"""
 
