@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # A module handling input, typically from various buttons, keyboard, sensors, etc.
@@ -18,20 +17,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_module import ranaModule
+from modules.base_module import RanaModule
 
 def getModule(m,d,i):
-  return(input(m,d,i))
+  return Input(m,d,i)
 
-class input(ranaModule):
+class Input(RanaModule):
   """Handle input from keyboard, buttons, etc."""
   
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
-    
-
-if(__name__ == "__main__"):
-  a = example({}, {})
-  a.update()
-  a.update()
-  a.update()
+    RanaModule.__init__(self, m, d, i)
\ No newline at end of file
