@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # A module handling input from keyboard, hardware buttons, sensors, etc.
@@ -18,7 +17,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_module import ranaModule
+from modules.base_module import RanaModule
 
 # only import GKT libs if GTK GUI is used
 from core import gs
@@ -27,13 +26,13 @@ if gs.GUIString == "GTK":
 
 
 def getModule(m,d,i):
-  return(keys(m,d,i))
+  return Keys(m,d,i)
 
-class keys(ranaModule):
+class Keys(RanaModule):
   """A keyboard input handling module"""
   
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
+    RanaModule.__init__(self, m, d, i)
 
   def firstTime(self):
     # connect the key press handler
@@ -57,11 +56,4 @@ class keys(ranaModule):
     elif keyName == 'F7':
       """zoom in"""
       self.sendMessage('mapView:zoomIn')
-    print "unassigned key pressed: %s" % keyName
-    
-
-if(__name__ == "__main__"):
-  a = example({}, {})
-  a.update()
-  a.update()
-  a.update()
+    print("unassigned key pressed: %s" % keyName)
\ No newline at end of file
