@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # Handle menus
@@ -18,11 +17,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_module import ranaModule
+from modules.base_module import RanaModule
 import time
 import math
-import geo
-import modrana_utils
+from core import geo
+from core import utils
 
 # only import GKT libs if GTK GUI is used
 from core import gs
@@ -32,12 +31,12 @@ if gs.GUIString == "GTK":
   import pangocairo
 
 def getModule(m,d,i):
-  return(menus(m,d,i))
+  return Menus(m,d,i)
 
-class menus(ranaModule):
+class Menus(RanaModule):
   """Handle menus"""
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
+    RanaModule.__init__(self, m, d, i)
     self.menus = {}
     self.lists = {}
     self.listOffset = 0
@@ -55,6 +54,10 @@ class menus(ranaModule):
 
     # colors - fail-safe defaults
     self.mainTextColor = (0,0,0.3,1)
+    self.scalebarColor = (0,0,0,1)
+    self.scalebarTextColor = (0,0,0,1)
+    self.scalebarTextBgColor = (1,1,1,1)
+    self.mainFillColor = (1,1,1,1)
     self.centerButtonCircleColor = (0,0,1,0.45)
     self.spButtonFillTup = ("#ffec8b",1.0)
     self.spButtonOutlineTup = ("#8b814c",1.0)
@@ -173,9 +176,9 @@ class menus(ranaModule):
       (x1,y1) = buttons['fullscreen']
       self.drawButton(cr, x1, y1, dx, dy, "", icon, "ms:display:fullscreen:toggle")
 
-      # * draw the centering button
+      # draw the centering button
       (x1,y1) = buttons['centre']
-      self.drawButton(cr, x1, y1, dx, dy, "", '', "toggle:centred")
+      self.drawButton(cr, x1, y1, dx, dy, "", 'generic:;0.5;;0.5;;', "toggle:centred")
 
       # the central circle
       cr.stroke()
@@ -221,12 +224,12 @@ class menus(ranaModule):
     """convenience function for asking for redraw"""
     self.set('needRedraw', True)
 
-  def showText(self,cr,text,x,y,widthLimit=None,fontsize=40,colorString=None):
+  def showText(self,cr,text,x,y,widthLimit=None,fontSize=40,colorString=None):
     pg = pangocairo.CairoContext(cr)
     # create a layout for your drawing area
     layout = pg.create_layout()
     layout.set_markup(text)
-    layout.set_font_description(pango.FontDescription("Sans Serif %d" % fontsize))
+    layout.set_font_description(pango.FontDescription("Sans Serif %d" % fontSize))
     (lw,lh) = layout.get_size()
     if lw == 0 or lh == 0:
       return # no need to draw this + avoid a division by zero
@@ -245,13 +248,13 @@ class menus(ranaModule):
       cr.move_to(x,y)
       pg.show_layout(layout)
 
-  def showWrappedText(self,cr,text,x,y,widthLimit,fontsize=20):
+  def showWrappedText(self,cr,text,x,y,widthLimit,fontSize=20):
     pg = pangocairo.CairoContext(cr)
     # create a layout for your drawing area
     layout = pg.create_layout()
     layout.set_width(int(widthLimit*pango.SCALE))
     layout.set_wrap(pango.WRAP_WORD)
-    layout.set_font_description(pango.FontDescription("Sans Serif %d" % fontsize))
+    layout.set_font_description(pango.FontDescription("Sans Serif %d" % fontSize))
     layout.set_markup(text)
     cr.move_to(x,y)
     pg.show_layout(layout)
@@ -329,7 +332,7 @@ class menus(ranaModule):
         m.registerXYWH(x1,y1,w,h, action, timedAction)
 
   def resetMenu(self, menu=None):
-    print "Menu knows menu changed"
+    print("Menu knows menu changed")
     self.listOffset = 0
 
   def dragEvent(self,startX,startY,dx,dy,x,y):
@@ -339,7 +342,7 @@ class menus(ranaModule):
     list = self.lists.get(menuName, None)
     if list is not None:
       self.listOffset += dy
-      print "Drag in menu + %f = %f" % (dy,self.listOffset)
+      print("Drag in menu + %f = %f" % (dy,self.listOffset))
 
   def setItemMenuGrid(self, x1, y1, cols,rows,dx,dy):
     """generate an icon placement grid for a given number of
@@ -393,7 +396,7 @@ class menus(ranaModule):
         index = None
 
       if listName in self.lists.keys():
-#        print "drawing list: %s" % menuName
+#        print("drawing list: %s" % menuName)
         self.lists[listName].draw(cr, index) # draw the list
     elif menuName == 'listDetail':
       listName,index = args.split('#',1)
@@ -410,7 +413,7 @@ class menus(ranaModule):
     # Find the menu
     menu = self.menus.get(menuName, None)
     if menu is None:
-      print "Menu %s doesn't exist, returning to main screen" % menuName
+      print("Menu %s doesn't exist, returning to main screen" % menuName)
       self.set('menu', None)
       self.set('needRedraw', True)
       return
@@ -544,7 +547,7 @@ class menus(ranaModule):
     if type == 'list':
       self.lists[menu] = module
     else:
-      print "Can't register \"%s\" menu - unknown type" % type
+      print("Can't register \"%s\" menu - unknown type" % type)
 
   def initMenu(self,menu):
     """initialize menu a menu dictionary instance to default parameters"""
@@ -575,14 +578,15 @@ class menus(ranaModule):
     self.drawButton(cr, x, y, w, h, '', icon, parentAction, timedAction)
 
   def getClearedMenu(self, cancelButtonAction='set:menu:main'):
-    """clear a given itemized menu instance, add the ecape button and return it"""
+    """clear a given itemized menu instance, add the escape button and return it"""
     menu = self.getInitializedMenu()
     timedAction=(self.modrana.gui.msLongPress,"set:menu:None")
     item = self.generateItem("", "back", cancelButtonAction, "simple", timedAction)
     return self.addItemsToThisMenu(menu, [item])
 
-  def addItemsToThisMenu(self, menu, items=[]):
+  def addItemsToThisMenu(self, menu, items=None):
     """add items to a given itemized menu datastructure and return it"""
+    if not items: items = []
     if not menu:
       menu = self.getInitializedMenu()
     itemCount = menu['metadata']['itemCount']
@@ -692,7 +696,7 @@ class menus(ranaModule):
       items = [
       gi('here#route', 'generic', routing),
       gi('to POI#add', 'generic', 'ms:menu:handleToolsMenuPoint:store'), # TODO implement this
-      gi('clear all#results', 'generic', 'set:menu:None') # TODO implement this
+      gi('results#clear all', 'generic', 'set:menu:None') # TODO implement this
       ]
       # add the items to a menu
       menu = self.addItemsToThisMenu(menu, items)
@@ -702,9 +706,9 @@ class menus(ranaModule):
 
   def addPointListMenu(self, name, parentAction, points=None, goto='detail'):
     if points:
-      c = modrana_utils.SimpleListContainer(points)
+      c = utils.SimpleListContainer(points)
     else:
-      c = modrana_utils.SimpleListContainer()
+      c = utils.SimpleListContainer()
 
     def describePointGo2Map(point, index, name):
       mainText = point.getName()
@@ -732,15 +736,15 @@ class menus(ranaModule):
 
   def addListMenu(self, name, parentAction, items=None, descFunction=None, drawFunction=None):
     if items:
-      c = modrana_utils.SimpleListContainer(items)
+      c = utils.SimpleListContainer(items)
     else:
-      c = modrana_utils.SimpleListContainer()
+      c = utils.SimpleListContainer()
     newListableMenu = self.ListableMenu(name, self, c, parentAction, descFunction, drawFunction,4)
 
     self.lists[name] = newListableMenu
     return newListableMenu
   
-  class ListableMenu:
+  class ListableMenu(object):
     """a listable menu object"""
     def __init__(self, name, menus, container, parentAction, descFunction=None, drawFunction=None, displayedItems=3):
       """use custom item and description drawing functions, or use the default ones"""
@@ -891,7 +895,7 @@ class menus(ranaModule):
       oldAction = self.parentAction # save the previous back action
       self.parentAction = action # replace with the given one
       # restore by callback once the menu is left
-      self.menus.watch('menu', self._menuLeftCB, oldAction)
+      self.menus.watch('menu', self._menuLeftCB, [oldAction])
 
     def _menuLeftCB(self, key, old, new, oldAction):
       # restore the original back action
@@ -955,6 +959,7 @@ class menus(ranaModule):
     self.addItem('searchWhat', 'online#address', 'generic', 'search:searchAddress')
     self.addItem('searchWhat', 'online#wikipedia', 'generic', 'search:searchWikipedia')
     self.addItem('searchWhat', 'online#presets', 'generic', 'set:menu:searchWhere')
+    self.addItem('searchWhat', 'results#clear', 'generic', 'search:clearSearch|set:menu:None')
 
   def setupSearchMenus(self):
     """Create a load of menus that are just filters for OSM tags"""
@@ -1101,9 +1106,15 @@ class menus(ranaModule):
      POISelectedAction2 = "showPOI:routeToActivePOI"
      self.addItem('route', 'Here to POI', 'generic', "ml:showPOI:setupCategoryList:%s|set:menu:menu#list#POICategories" % POISelectedAction2)
      self.addItem('route', 'to Address#Address', 'generic', 'set:menu:route#showAddressRoute')
+     self.addItem('route', 'Handmade', 'generic', 'set:menu:None|route:handmade')
      self.addItem('route', 'Clear', 'generic', 'route:clear|set:menu:None')
      self.addItem('route', 'route#Current', 'generic', 'set:menu:currentRoute')
 
+  def setupTracklogsMenu(self):
+    self.clearMenu('tracklogs')
+    self.addItem('tracklogs', 'categories', 'generic', 'set:menu:tracklogManagerCategories')
+    self.addItem('tracklogs', 'visible#clear', 'generic', 'showTracklogs:clearVisible|set:menu:None')
+
   def setupInfoMenu(self):
     self.clearMenu('info')
     self.addItem('info', 'About', 'generic', 'set:menu:info#infoAbout')
@@ -1119,8 +1130,8 @@ class menus(ranaModule):
     self.addItem('main', 'options', 'options', 'set:menu:options')
     self.addItem('main', 'download', 'download', 'set:menu:data')
     self.addItem('main', 'mode', 'mode', 'set:menu:modes')
-    self.addItem('main', 'tracklogs', 'tracklogs', 'set:menu:tracklogManagerCategories')
     self.addItem('main', 'log a track', 'log', 'set:menu:tracklog#tracklog')
+    self.addItem('main', 'tracklogs', 'tracklogs', 'set:menu:tracklogs')
     self.addItem('main', 'info', 'info', 'set:menu:info')
     self.setupModesMenu()
     self.setupSearchMenus()
@@ -1130,6 +1141,7 @@ class menus(ranaModule):
     self.setupPoiMenu()
     self.setupDataMenu()
     self.setupRouteMenu()
+    self.setupTracklogsMenu()
     self.setupInfoMenu()
     self.clearMenu('options', "set:menu:main") # will be filled by mod_options
     self.lists['places'] = 'placenames'
@@ -1361,7 +1373,7 @@ class menus(ranaModule):
     else:
       text = "%1.1f km" % dist
 
-    cr.set_source_rgb(0,0,0)
+    cr.set_source_rgba(*self.scalebarColor)
     cr.move_to(x1,y1)
     cr.line_to(x2,y2)
     cr.stroke()
@@ -1370,9 +1382,11 @@ class menus(ranaModule):
 #    z = self.get('z', 15)
 #    text = text + " (zl%d)" % z
 
-    self.boxedText(cr, x1, y1-4, text, 12, 1)
+    self.boxedText(
+      cr, x1, y1-4, text, 12, 1, fg=self.scalebarTextColor, bg=self.scalebarTextBgColor
+    )
 
-  def boxedText(self, cr, x,y,text, size=12, align=1, border=2, fg=(0,0,0), bg=(1,1,1)):
+  def boxedText(self, cr, x,y,text, size=12, align=1, border=2, fg=(0,0,0,1), bg=(1,1,1,1)):
 
     cr.set_font_size(12)
     extents = cr.text_extents(text)
@@ -1390,17 +1404,21 @@ class menus(ranaModule):
     elif align in (4,5,6):
       y1 += 0.5 * h
 
-    cr.set_source_rgb(bg[0],bg[1],bg[2])
+    cr.set_source_rgba(*bg)
     cr.rectangle(x1 - border, y1 + border, w +2*border, -(h+2*border))
     cr.fill()
 
-    cr.set_source_rgb(fg[0],fg[1],fg[2])
+    cr.set_source_rgba(*fg)
     cr.move_to(x1,y1)
     cr.show_text(text)
     cr.fill()
 
   def colorsChangedCallback(self,colors):
     self.mainTextColor = colors['main_text'].getCairoColor()
+    self.scalebarColor = colors['scalebar_color'].getCairoColor()
+    self.scalebarTextColor = colors['scalebar_text'].getCairoColor()
+    self.scalebarTextBgColor = colors['scalebar_text_bg'].getCairoColor()
+
     self.centerButtonCircleColor = colors['center_button_circle'].getCairoColor()
     # normal
     sbFill = colors['special_button_fill']
@@ -1447,7 +1465,7 @@ class menus(ranaModule):
           print("menu: no list %s available, can't set index" % listName)
       except Exception, e:
         print("menu: setting list index failed")
-        print e
+        print(e)
 
     elif type == "ms" and message == "openUrl":
       url = args
@@ -1513,9 +1531,4 @@ class menus(ranaModule):
 
       self.set(uniqueName, newIndex)
       self.menus[menu][pos] = (textIconAction, newIndex, uniqueName, type)
-
-if(__name__ == "__main__"):
-  a = menus({},{'viewport':(0,0,600,800)})
-  #a.drawMapOverlay(None)
-  a.setupSearchMenus()
   
\ No newline at end of file
