@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # A module handling unit conversions and displaying correct units according to current settings.
@@ -18,40 +17,55 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_module import ranaModule
+from modules.base_module import RanaModule
 import time
 
 def getModule(m,d,i):
-  return(units(m,d,i))
+  return Units(m,d,i)
 
-class units(ranaModule):
+class Units(RanaModule):
   """a unit handling module """
   
   mileInMeters = 1609.344
   mileInKiloMeters = mileInMeters / 1000
   mileInFeet = 5280
+  mileInYards = 1760
   footInMeters = 0.3048
+  yardInMeters = 0.9144
+
 
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
+    RanaModule.__init__(self, m, d, i)
     """
     # we consider 2km/h as as stationary 
     (to filter out the standard GPS drift while not moving)
     """
     self.notMovingSpeed  = 2
-    
+    self._updateUnitTable()
+
+  def _updateUnitTable(self):
+    # TODO: unit localization support
+    # TODO: different global & routing unit localization support
+    self.unitTable = {
+      'km' : Unit(('m', 'meter', 'meters'), ('km', 'kilometer', 'kilometers'), type='km'),
+      'miles' : Unit(('yd', 'yard', 'yards'), ('mi', 'mile', 'miles'), type='miles'),
+      'milesFeet' : Unit(('ft', 'foot', 'feet'), ('mi', 'mile', 'miles'), type='miles', subType='feet'),
+    }
+
   def m2km(self, m):
-    return (m / 1000.0) # m to km
+    return m / 1000.0 # m to km
 
   def km2m(self, km):
-    return (km * 1000) # km to m
+    return km * 1000 # km to m
 
   def km2Miles(self, km):
     return km / self.mileInKiloMeters  # km to miles
 
   def miles2Feet(self, miles):
-    return miles*self.mileInFeet
+    return miles * self.mileInFeet
 
+  def miles2Yards(self, miles):
+    return miles * self.mileInYards
 
   def m2CurrentUnit(self, m):
     return self.km2CurrentUnit(m*1000)
@@ -69,18 +83,23 @@ class units(ranaModule):
 
   def km2CurrentUnitString(self, km, dp=None, short=True):
     """return current unit in string with unit descriptor, rounded to two decimal places"""
-    unitType = self.get("unitType", "km")
+    # get current unit
+    unit = self.getCurrentUnit()
+
     small = False
-    if unitType == 'km':
+    if unit.type == 'km':
       if km <= 1: # we now count in meters
         dp = -1 # no need to count the odd meter with current GPS accuracy
-        distance = km*1000
+        distance = km * 1000
         small = True
       else:
         distance = km
     else: # just miles for now
-      if km<self.mileInKiloMeters / 10:
-        distance = self.km2Miles(km) * self.mileInFeet
+      if km < self.mileInKiloMeters / 10:
+        if unit.subType == 'feet':
+          distance = self.km2Miles(km) * self.mileInFeet
+        else:
+          distance = self.km2Miles(km) * self.mileInYards
         dp = -1 # no need to count the odd foot with current GPS accuracy
         small = True
       else:
@@ -89,7 +108,7 @@ class units(ranaModule):
     # rounding
     if dp is None:
       numberString = "%f" % distance
-    elif dp==0:
+    elif dp == 0:
       n = int(round(distance, 0))
       numberString = "%d" % n
     else:
@@ -101,33 +120,17 @@ class units(ranaModule):
     #is it a string float representation ?
     if '.' in numberString: # strip possible trailing zeroes
       numberString = numberString.rstrip('0').rstrip('.')
-      
-    # short/lon unit name
-    if unitType == 'km':
-      if short:
-        unitString = "km"
-        smallUnitString = "m"
-      else:
-        unitString = "kilometers"
-        smallUnitString = "meters"
 
+    if short:
       if small:
-        return "%s %s" % (numberString, smallUnitString)
+        return "%s %s" % (numberString, unit.smallShort)
       else:
-        return "%s %s" % (numberString, unitString)
-      
-    else: # miles
-      if short:
-        unitString = "mi"
-        smallUnitString = "ft"
-      else:
-        unitString = "miles"
-        smallUnitString = "feet"
-
+        return "%s %s" % (numberString, unit.normalShort)
+    else:
       if small:
-        return "%s %s" % (numberString, smallUnitString)
+        return "%s %s" % (numberString, unit.smallP)
       else:
-        return "%s %s" % (numberString, unitString)
+        return "%s %s" % (numberString, unit.normalP)
 
   def km2CurrentUnitStringFullName(self, km):
     """return current unit in string with unit descriptor, rounded to two decimal places"""
@@ -227,7 +230,7 @@ class units(ranaModule):
         return "feet"
 
   def currentSpeedUnitToMS(self, currentSpeedUnit):
-    "convert current speed unit to meters per second"
+    """convert current speed unit to meters per second"""
     unitType = self.get("unitType", "km")
     if unitType == 'km':
       return currentSpeedUnit * 0.277778
@@ -236,7 +239,7 @@ class units(ranaModule):
 
   def getCurrentTimeString(self, timeFormat=None):
     """return a string with current time, the format can be set or a system defined one is used"""
-    if timeFormat == None:
+    if timeFormat is None:
       timeFormat = self.get('currentTimeFormat', '24h')
     if timeFormat == "12h":
       return time.strftime("%I:%M %p")
@@ -256,9 +259,9 @@ class units(ranaModule):
        None if the current speed is unknown
        """
 
-    currentspeedKMH = self.get('speed', None)
-    if currentspeedKMH is not None:
-      return currentspeedKMH>self.notMovingSpeed
+    currentSpeedKMH = self.get('speed', None)
+    if currentSpeedKMH is not None:
+      return currentSpeedKMH>self.notMovingSpeed
     else:
       # signalise that we can't decide this
       return None
@@ -272,6 +275,7 @@ class units(ranaModule):
   meters = ('m', 'meter', 'meters', 1)
   kilometers = ('km', 'kilometer', 'kilometers', 1.0 / 1000)
   feet = ('ft', 'foot', 'feet', 1.0 / footInMeters)
+  yards = ('yd', 'yard', 'yards', 1.0 / yardInMeters)
   miles = ('mi', 'mile', 'miles', 1.0 / mileInMeters)
   #
   # Table of how to round.  There is one dictionary entry for each
@@ -337,10 +341,31 @@ class units(ranaModule):
       long = unitDescription[1]
     else:
       long = unitDescription[2]
-    return (distanceString, unitDescription[0], long)
+    return distanceString, unitDescription[0], long
+
+  def getCurrentUnit(self, short = True):
+    """return a dict containing unit names corresponding to the current
+    unit configuration"""
+
+    #TODO: cache the result & watch for option changes ?
+    unitType = self.get("unitType", "km")
+    unitTypeImperialSmall = self.get("unitTypeImperialSmall", "yards")
+
+    if unitType == 'km':
+      return self.unitTable['km']
+    else: # imperial units
+      if unitTypeImperialSmall == 'feet':
+        return self.unitTable['milesFeet']
+      else: # default - yards
+        return self.unitTable['miles']
+
+class Unit(object):
+  """represents an unit of distance in several denominations and name types"""
+  def __init__(self, small, normal, type = None, subType = None):
+    # P = plural
+    self.smallShort, self.small, self.smallP = small
+    self.normalShort, self.normal, self.normalP = normal
+    self.type = type
+    self.subType = subType
+
 
-if(__name__ == "__main__"):
-  a = example({}, {})
-  a.update()
-  a.update()
-  a.update()
